This enumeration type is not currently used.

Field field_value_type in dfield definitions contains a type URI.

It is not clear tio me (GK) at the time of writing this (Dec 2016) if
this is a depercated option from, an earlier design, or an experimental
future design option.  The fiule "Value_types.md" suggests the latter.
